Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(97)

Unified Diff: Source/platform/fonts/skia/SimpleFontDataSkia.cpp

Issue 182923003: Chrome not considering Underline Position from Font (Closed) Base URL: https://chromium.googlesource.com/chromium/blink.git@master
Patch Set: Adding comments and updating check for Underline Pos Created 6 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: Source/platform/fonts/skia/SimpleFontDataSkia.cpp
diff --git a/Source/platform/fonts/skia/SimpleFontDataSkia.cpp b/Source/platform/fonts/skia/SimpleFontDataSkia.cpp
index 748bed89c36b7bb1cf9d647b8fb77c1a10932e40..0a32d02363d6a8e7969a943befb6dbff106a8a00 100644
--- a/Source/platform/fonts/skia/SimpleFontDataSkia.cpp
+++ b/Source/platform/fonts/skia/SimpleFontDataSkia.cpp
@@ -133,11 +133,17 @@ void SimpleFontData::platformInit()
m_fontMetrics.setLineGap(lineGap);
m_fontMetrics.setLineSpacing(lroundf(ascent) + lroundf(descent) + lroundf(lineGap));
// For now Skia does not support underline Thickness, once patch is comitted we can uncomment following
// code, till then setting Underline Thickness to Zero so that default calculation is done.
eae 2014/02/28 17:37:59 Could you add a FIXME comment with a link to the b
h.joshi 2014/03/01 03:36:12 Will add FIXME comment in next patch. On 2014/02/
+
// float underlineThickness = SkScalarToFloat(metrics.fUnderlineThickness);
// m_fontMetrics.setUnderlineThickness(underlineThickness);
+
+ // float underlinePosition = SkScalarToFloat(metrics.fUnderlinePosition);
+ // m_fontMetrics.setUnderlineThickness(underlinePosition);
m_fontMetrics.setUnderlineThickness(0.f);
+ m_fontMetrics.setUnderlinePosition(0.f);
if (platformData().orientation() == Vertical && !isTextOrientationFallback()) {
static const uint32_t vheaTag = SkSetFourByteTag('v', 'h', 'e', 'a');
« Source/core/rendering/InlineTextBox.cpp ('K') | « Source/platform/fonts/mac/SimpleFontDataMac.mm ('k') | no next file » | no next file with comments »
@@ -133,11 +133,17 @@ void SimpleFontData::platformInit()
m_fontMetrics.setLineGap(lineGap);
m_fontMetrics.setLineSpacing(lroundf(ascent) + lroundf(descent) + lroundf(lineGap));
- // For now Skia does not support underline Thickness, once patch is comitted we can uncomment following
- // code, till then setting Underline Thickness to Zero so that default calculation is done.
+ // For now Skia does not support underline Thickness and Position, once submitted patch is comitted
+ // we can uncomment following code, till then setting Underline Thickness and Position to Zero so that
+ // default calculation is done.
eae 2014/02/28 17:37:59 Could you add a FIXME comment with a link to the b
h.joshi 2014/03/01 03:36:12 Will add FIXME comment in next patch. On 2014/02/

Powered by Google App Engine
This is Rietveld 408576698